@@ -699,7 +699,7 @@ class Manager(GObject.Object):
 
     def tool_changed(self, tool, refresh=False):
         for row in self._tool_rows[tool]:
-            self.model.row_changed(row.get_path(), self.model.get_iter(row.get_path()))
+            self.model.set_value(self.model.get_iter(row.get_path()), self.TOOL_COLUMN, tool)
 
         if refresh and tool == self.current_node:
             self.fill_fields()
@@ -732,7 +732,7 @@ class Manager(GObject.Object):
             if language in node.languages:
                 node.languages.remove(language)
 
-            self._tool_rows[node] = filter(lambda x: x.valid(), self._tool_rows[node])
+            self._tool_rows[node] = [x for x in self._tool_rows[node] if x.valid()]
 
             if not self._tool_rows[node]:
                 del self._tool_rows[node]
@@ -909,7 +909,9 @@ class Manager(GObject.Object):
             escaped = saxutils.escape(tool.name)
 
             if tool.shortcut:
-                markup = '%s (<b>%s</b>)' % (escaped, saxutils.escape(tool.shortcut))
+                key, mods = Gtk.accelerator_parse(tool.shortcut)
+                label = Gtk.accelerator_get_label(key, mods)
+                markup = '%s (<b>%s</b>)' % (escaped, label)
             else:
                 markup = escaped
 
