@@ -1094,12 +1094,6 @@ model_sort_default (FileBrowserNode *node1,
 	if (f1 != f2)
 		return f1 ? -1 : 1;
 
-	f1 = NODE_IS_HIDDEN (node1);
-	f2 = NODE_IS_HIDDEN (node2);
-
-	if (f1 != f2)
-		return f2 ? -1 : 1;
-
 	return collate_nodes (node1, node2);
 }
 
@@ -1664,6 +1658,10 @@ model_recomposite_icon_real (GeditFileBrowserStore *tree_model,
 		icon = gedit_file_browser_utils_pixbuf_from_file (node->file, GTK_ICON_SIZE_MENU, FALSE);
 	}
 
+	/* Fallback to the same icon as the file browser */
+	if (!icon)
+		icon = gedit_file_browser_utils_pixbuf_from_theme ("text-x-generic", GTK_ICON_SIZE_MENU);
+
 	if (node->icon)
 		g_object_unref (node->icon);
 
